==> flutter_ads-0.2.0.tar.gz: lib/ads_bannerview.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_ads/flutter_ads.dart';

typedef AdsIsFinish = void Function();

typedef AdsIsFailure = void Function();

typedef AdsTick = void Function(num);

class AdsBannerView extends StatefulWidget {
  final AdsIsFinish asdIsFinish;
  final AdsTick adsTick;
  final AdsIsFailure adsFailure;

  const AdsBannerView(
      {Key key, this.asdIsFinish, this.adsTick, this.adsFailure})
      : super(key: key);

  @override
  _AdsBannerViewState createState() => _AdsBannerViewState();
}

// 设置事件监听方法
class _AdsBannerViewState extends State<AdsBannerView> {
  var boolOffstate = true;
  var tempHeight = FlutterAds.maxBannerHeight;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Stack(
        children: <Widget>[
          SizedBox(
            height: tempHeight,
            child: AndroidView(
              viewType: 'plugins.nova.ads/bannerview',
              onPlatformViewCreated: (id) async {
                MethodChannel _channel =
                    new MethodChannel('plugins.nova.ads/bannerview_$id');
                _channel.setMethodCallHandler((call) {
                  if (call.method == 'height') {
                    int height = call.arguments;
                    tempHeight = height.toDouble();
                    boolOffstate = false;
                    print("banner$height");
                    Future.delayed(Duration(milliseconds: 300), () {
                      setState(() {});
                    });
                  }
                });
              },
              creationParamsCodec: const StandardMessageCodec(),
            ),
          ),
          Offstage(
              offstage: boolOffstate,
              child: Container(
                color: FlutterAds.mbannerMaskColor,
              ))
        ],
      );
    } else {
      return UiKitView(viewType: 'plugins.nova.ads/bannerview');
    }
  }
}

==> flutter_ads-0.4.1.tar.gz: lib/ads_bannerview.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_ads/flutter_ads.dart';

typedef AdsIsFinish = void Function();

typedef AdsIsFailure = void Function();

typedef AdsTick = void Function(num);

class AdsBannerView extends StatefulWidget {
  final AdsIsFinish asdIsFinish;
  final AdsTick adsTick;
  final AdsIsFailure adsFailure;

  const AdsBannerView(
      {Key key, this.asdIsFinish, this.adsTick, this.adsFailure})
      : super(key: key);

  @override
  _AdsBannerViewState createState() => _AdsBannerViewState();
}

// 设置事件监听方法
class _AdsBannerViewState extends State<AdsBannerView> {
  var boolOffstate = false;
  var tempHeight = FlutterAds.maxBannerHeight;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Stack(
        children: <Widget>[
          SizedBox(
            height: tempHeight,
            child: AndroidView(
              viewType: 'plugins.nova.ads/bannerview',
              onPlatformViewCreated: (id) async {
                MethodChannel _channel =
                    new MethodChannel('plugins.nova.ads/bannerview_$id');
                _channel.setMethodCallHandler((call) {
                  if (call.method == 'height') {
                    int height = call.arguments;
                    tempHeight = height.toDouble();
                    boolOffstate = true;
                    print("banner$height");
                    Future.delayed(Duration(milliseconds: 500), () {
                      setState(() {});
                    });
                  }
                });
              },
              creationParamsCodec: const StandardMessageCodec(),
            ),
          ),
          Offstage(
              offstage: boolOffstate,
              child: Container(
                color: FlutterAds.mbannerMaskColor,
              ))
        ],
      );
    } else {
      return UiKitView(viewType: 'plugins.nova.ads/bannerview');
    }
  }
}
